# Adabas-Routinen geklaut aus tkquery con Christian Krohne
# 
proc ermtkcompat {} {
  global tkCompat tcl_version tk_version tk_patchLevel
# ----------------------------------------------------------------------
# Is Tk loaded at all? This error can happen, if e.g. the DISPLAY
# variable isn't set or points to the wrong display. Since the X server
# already complained to stdout, our messages here can be rather terse.
# ----------------------------------------------------------------------

   if [catch {package require Tk}] {
       puts "GUI not available. Exited"
       exit 3
   }

# ----------------------------------------------------------------------
# Now we have to do some limbo to get TclTk's version clear.
# 1. The argument of the -weight option of the grid command changed
#    from float into an integer.
# 2. Are we running as plugin or have a Tk version, that is capable of
#    reading gif out of the -data option?
# 3. Do we have a Tk with the new font command?
# 4. Do we have a Tk with the new menu bar mechanism?
# 5. Do we have a Tk with native dialogs (tk_messageBox/tk_getOpenFile)?
# 6. Do we have the "file delete" subcommand?
# 7. Do we have a Tk, where buttons understand the -default option?
# ----------------------------------------------------------------------

   set tkCompat(gridWeightMax) [expr $tk_version  >= 4.2 ? 100 : 1.0]
   set tkCompat(gridWeightMin) [expr $tk_version  >= 4.2 ?   0 : 0.0]
   set tkCompat(imageViaData)  [expr $tk_version  >= 8.0 || [info exists embed_args]]
   set tkCompat(fontCmd)       [expr $tk_version  >= 8.0]
   set tkCompat(menubars)      [expr $tk_version  >= 8.0]
   set tkCompat(nativeDialogs) [expr $tk_version  >= 4.2]
   set tkCompat(fileDelCmd)    [expr $tcl_version >= 7.6]
   switch -glob $tk_patchLevel {
       tk8.0a? - tk8.0b1 {set tkCompat(defaultButton) 1}
       tk[89]*           {set tkCompat(defaultButton) normal}
   }
}
proc loadAdabastcl {} {
    global env auto_path

    if ![info exists env(DBROOT)] {
	append err "This application is only functional, if the environment " \
		"variable DBROOT is set correctly."

	tk_dialog .err "Fatal error" $err questhead 0 Exit  
        exit 1
    }

    # We better put our directories at the front of the path...
    set auto_path [linsert $auto_path 0 $env(DBROOT)/lib $env(DBROOT)/tcl]

    if [catch {package require Adabastcl} msg] {
	append err "This application is only functional with the Adabastcl " \
		"extension. While starting it, the following error occurs:" \
		"\n\n$msg\n\n" \
		"You must have set DBROOT correctly (its current value is " \
		"$env(DBROOT)) and you have to have an installed " \
		"AdabasTcl extension to the Adabas D database server."

	tk_dialog .err "Fatal error" $err questhead 0 Exit  
        exit 2
    }

    # Just to be sure, that the extension is loaded. "package require" does
    # not actually load the shared library, but adds the commands only to the
    # list of the unknown procedures; this applies not to variables - and we
    # will need adabastcl_library more or less immediately.
    adabas version

    # We switch on the trace, if the appropriate environment variable is set.
    if [info exists env(ADABASTCL_TRACE)] {
	global adamsg
	set adamsg(tracefile) $env(ADABASTCL_TRACE)
    }
}
# ---------------------------------------------------------------------
# 'adaConnect' will be called, when the user presses the Connect button
# in the connect dialog. It tries to connect with the given user/password
# combination to the database, and sets - if succesful - the global
# variables 'logon' (login handle) and 'cursor'.
# ---------------------------------------------------------------------
proc adaConnect {} {
    global connect logon cursor

    if ![tryConnect] {return 0}

    set logon $connect(db)
    set cursor [adaopen $logon]

    return 1
}

proc adabasende {} {
  global logon cursor
  adaclose $cursor
  adalogoff $logon
}

proc setdateformat { f } {
  global cursor adamsg
  catch { adasql $cursor "SET FORMAT $f" } error
  if { $adamsg(rc) != 0 } {
     append err "Can't set Dateformat $f "
     tk_dialog .err "Fatal error" $err questhead 0 Exit
     exit 1
  }  
}
#Beispiel
#ermtkcompat
#loadAdabastcl
#getDbnameUserPassword "Authorisierung Adabas " adaConnect
#setdateformat eur
